@@ -3,7 +3,7 @@ use 5.020;
 use strict;
 use warnings;
 
-our $VERSION = "1.3.0";
+our $VERSION = "1.3.1";
 
 use Moose;
 use HTTP::Tiny;
@@ -71,7 +71,7 @@ sub http_request ($self, $method, $url, $headers = {}, $content = '') {
             }
         );
 
-        if ($response->{status} == 599) {
+        if ($response->{status} == 599 || ($response->{status} == 401 && !$response->{reason})) {
             $log->info("Authentification to teamcity failed, retrying.");
             die 'Authentification to teamcity failed';
         }
